#ifndef NT2_CORE_INCLUDE_FUNCTIONS_SCALAR_SUB2IND_HPP_INCLUDED
#define NT2_CORE_INCLUDE_FUNCTIONS_SCALAR_SUB2IND_HPP_INCLUDED

#include <nt2/core/functions/sub2ind.hpp>
#include <nt2/core/functions/generic/sub2ind.hpp>

#endif
